import re
from dosage.modules.helpers.BasicComicModule import BasicComicModule

class WhiteNinja(BasicComicModule):
    latestUrl = 'http://www.whiteninjacomics.com/comics.shtml'
    imageUrl = 'http://www.whiteninjacomics.com/comics/%s.shtml'
    imageSearch = re.compile(r'<img src=(/images/comics/(?!t-).+?\.gif) border=0', re.IGNORECASE)
    prevSearch = re.compile(r'(/comics/.+?shtml).+?previous')
    help = 'Index format: s (comic name)'
